@@ -1,16 +1,16 @@
 from .api import distribution, Distribution, PackageNotFoundError  # noqa: F401
-from .api import metadata, entry_points, resolve, version, read_text
+from .api import metadata, entry_points, version, files, requires
 
 # Import for installation side-effects.
 from . import _hooks  # noqa: F401
 
 
 __all__ = [
-    'metadata',
     'entry_points',
-    'resolve',
+    'files',
+    'metadata',
+    'requires',
     'version',
-    'read_text',
     ]
 
 
