@@ -2,13 +2,13 @@ import sys
 import unittest
 import importlib_metadata
 
+from importlib_resources import path
+
 try:
     from contextlib import ExitStack
 except ImportError:
     from contextlib2 import ExitStack
 
-from importlib_resources import path
-
 
 class BespokeLoader:
     archive = 'bespoke'
@@ -30,9 +30,9 @@ class TestZip(unittest.TestCase):
         self.assertEqual(importlib_metadata.version('example'), '21.12')
 
     def test_zip_entry_points(self):
-        parser = importlib_metadata.entry_points('example')
-        entry_point = parser.get('console_scripts', 'example')
-        self.assertEqual(entry_point, 'example:main')
+        scripts = dict(importlib_metadata.entry_points()['console_scripts'])
+        entry_point = scripts['example']
+        self.assertEqual(entry_point.value, 'example:main')
 
     def test_missing_metadata(self):
         distribution = importlib_metadata.distribution('example')
@@ -40,3 +40,9 @@ class TestZip(unittest.TestCase):
 
     def test_case_insensitive(self):
         self.assertEqual(importlib_metadata.version('Example'), '21.12')
+
+    def test_files(self):
+        files = importlib_metadata.files('example')
+        for file in files:
+            path = str(file.dist.locate_file(file))
+            assert '.whl/' in path, path
